.. _eric-espinoza:

Eric Espinoza
:::::::::::::::::::::::::::::::::::::

.. role:: raw-html(raw)
   :format: html

:raw-html:`<font color="CadetBlue"><em>"I don't think that your identity has to be tied to what you do. If anything, the skills needed for the job — learning new ideas and new technologies — identifies an individual that likes to play with things."</em></font>`

**Why did he choose computing?**

*"I love the possibility that with the knowledge and the skills, a small type of computing instrument and the resource of time and discipline, sky is the limit. So I really like the opportunity to create anything really."*

Like countless other programmers, Eric enjoys how programming enables him to build whatever he can think of, whether it's helping him, his employer, or the world.

**How did he pursue computing?**

Eric studied at a full-stack boot camp — a boot camp that teaches both front-end (constructing the components that users interact with) and back-end development (building the technologies that facilitate the front end).

**What subfield is he working in?**

*"Yeah, I'm a DevOps engineer — [a role that] basically writes code that works within a company so that a developer can use that pipeline that I helped create. And they can send that code throughout the company so that the customer never sees the test code or the code that's in work — they only see the final product. The work that I do is creating the pipeline to take the code that the developers use from start to finish."*

**Who does he look up to?**

*"[A big mentor] was a teacher that basically showed me the way to speak. I took more than just the coding skills themselves. I was able to see that person as a mentor beyond just coding and see their accomplishments and what they were able to do beyond it and then also why they code. It was lucky to find a master in the field that not only was a very technically inclined and skilled coder but also just a general good human being that I respected and admired."*